@@ -15,17 +15,24 @@ DeleteTextUndoCommand::DeleteTextUndoCommand(QTextCursor textcursor, TextEdit *e
     , m_textCursor(textcursor)
     , m_beginPos(m_textCursor.selectionStart())
 {
+    qDebug() << "DeleteTextUndoCommand created - beginPos:" << m_beginPos;
+
     if (m_textCursor.hasSelection()) {
+        qDebug() << "m_textCursor.hasSelection()";
         m_sInsertText = m_textCursor.selectedText();
     } else {
+        qDebug() << "m_textCursor.hasSelection() is false";
         int pos = m_textCursor.positionInBlock() - 1;
         if (pos >= 0) {
+            qDebug() << "pos >= 0";
             m_sInsertText = m_textCursor.block().text().at(pos);
         } else {
             //上一行lastQChar
+            qDebug() << "pos < 0";
             m_sInsertText = "\n";
         }
     }
+    qDebug() << "DeleteTextUndoCommand created end";
 }
 
 DeleteTextUndoCommand::DeleteTextUndoCommand(QList<QTextEdit::ExtraSelection> &selections,
@@ -36,26 +43,35 @@ DeleteTextUndoCommand::DeleteTextUndoCommand(QList<QTextEdit::ExtraSelection> &s
     , m_ColumnEditSelections(selections)
     , m_beginPos(m_textCursor.selectionStart())
 {
+    qDebug() << "DeleteTextUndoCommand created - beginPos:" << m_beginPos;
     int cnt = m_ColumnEditSelections.size();
     for (int i = 0; i < cnt; i++) {
         QTextCursor textCursor = m_ColumnEditSelections[i].cursor;
         if (textCursor.hasSelection()) {
+            qDebug() << "textCursor.hasSelection()";
             m_selectTextList.append(textCursor.selectedText());
         } else {
             int pos = textCursor.positionInBlock() - 1;
             if (pos >= 0) {
+                qDebug() << "pos >= 0";
                 m_selectTextList.append(textCursor.block().text().at(pos));
             } else {
                 //上一行lastQChar
+                qDebug() << "pos < 0";
                 m_selectTextList.append("\n");
             }
         }
     }
+    qDebug() << "DeleteTextUndoCommand created end";
 }
 
 void DeleteTextUndoCommand::undo()
 {
+    qDebug() << "DeleteTextUndoCommand undo - beginPos:" << m_beginPos
+                << ", text length:" << m_sInsertText.length();
+
     if (m_ColumnEditSelections.isEmpty()) {
+        qDebug() << "m_ColumnEditSelections.isEmpty()";
         // 插入前将光标恢复到删除前位置
         m_textCursor.setPosition(m_beginPos);
         m_textCursor.insertText(m_sInsertText);
@@ -66,6 +82,7 @@ void DeleteTextUndoCommand::undo()
             m_edit->setTextCursor(m_textCursor);
         }
     } else {
+        qDebug() << "m_ColumnEditSelections.isEmpty() is false";
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_ColumnEditSelections[i].cursor.insertText(m_selectTextList[i]);
@@ -74,15 +91,20 @@ void DeleteTextUndoCommand::undo()
         }
 
         if (m_edit && !m_ColumnEditSelections.isEmpty()) {
+            qDebug() << "m_edit is not null";
             m_edit->restoreColumnEditSelection(m_ColumnEditSelections);
             m_edit->setTextCursor(m_ColumnEditSelections.last().cursor);
         }
     }
+    qDebug() << "DeleteTextUndoCommand undo end";
 }
 
 void DeleteTextUndoCommand::redo()
 {
+    qDebug() << "DeleteTextUndoCommand redo - beginPos:" << m_beginPos;
+
     if (m_ColumnEditSelections.isEmpty()) {
+        qDebug() << "m_ColumnEditSelections.isEmpty()";
         m_textCursor.deletePreviousChar();
 
         // 进行撤销/恢复时将光标移动到撤销位置
@@ -90,22 +112,31 @@ void DeleteTextUndoCommand::redo()
             m_edit->setTextCursor(m_textCursor);
         }
     } else {
+        qDebug() << "m_ColumnEditSelections.isEmpty() is false";
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_ColumnEditSelections[i].cursor.deletePreviousChar();
         }
 
         if (m_edit && !m_ColumnEditSelections.isEmpty()) {
+            qDebug() << "m_edit is not null";
             m_edit->restoreColumnEditSelection(m_ColumnEditSelections);
             m_edit->setTextCursor(m_ColumnEditSelections.last().cursor);
         }
     }
+    qDebug() << "DeleteTextUndoCommand redo end";
 }
 
 int DeleteTextUndoCommand::id() const
 {
-    return m_ColumnEditSelections.isEmpty() ? Utils::IdDelete
-                                            : Utils::IdColumnEditDelete;
+    qDebug() << "DeleteTextUndoCommand id";
+    if (m_ColumnEditSelections.isEmpty()) {
+        qDebug() << "m_ColumnEditSelections.isEmpty()";
+        return Utils::IdDelete;
+    } else {
+        qDebug() << "m_ColumnEditSelections.isEmpty() is false";
+        return Utils::IdColumnEditDelete;
+    }
 }
 
 DeleteTextUndoCommand2::DeleteTextUndoCommand2(QTextCursor textcursor, QString text, QPlainTextEdit *edit, bool currLine)
@@ -114,6 +145,7 @@ DeleteTextUndoCommand2::DeleteTextUndoCommand2(QTextCursor textcursor, QString t
     , m_edit(edit)
     , m_iscurrLine(currLine)
 {
+    qDebug() << "DeleteTextUndoCommand2 created";
     m_sInsertText.replace("\r\n", "\n");
 }
 
@@ -126,32 +158,40 @@ DeleteTextUndoCommand2::DeleteTextUndoCommand2(QList<QTextEdit::ExtraSelection>
     , m_edit(edit)
     , m_iscurrLine(currLine)
 {
+    qDebug() << "DeleteTextUndoCommand2 created";
     m_sInsertText.replace("\r\n", "\n");
     int cnt = m_ColumnEditSelections.size();
     for (int i = 0; i < cnt; i++) {
         QTextCursor textCursor = m_ColumnEditSelections[i].cursor;
         if (textCursor.hasSelection()) {
+            qDebug() << "textCursor.hasSelection()";
             m_selectTextList.append(textCursor.selectedText());
         } else {
             int pos = textCursor.positionInBlock() - 1;
             if (pos >= 0) {
+                qDebug() << "pos >= 0";
                 m_selectTextList.append(textCursor.block().text().at(pos));
             } else {
                 //上一行lastQChar
+                qDebug() << "pos < 0";
                 m_selectTextList.append("\n");
             }
         }
     }
+    qDebug() << "DeleteTextUndoCommand2 created end";
 }
 
 void DeleteTextUndoCommand2::undo()
 {
+    qDebug() << "DeleteTextUndoCommand2 undo";
     if (m_ColumnEditSelections.isEmpty()) {
+        qDebug() << "m_ColumnEditSelections.isEmpty()";
         m_textCursor.setPosition(m_beginPostion);
         m_textCursor.insertText(m_sInsertText);
         m_textCursor.setPosition(m_beginPostion);
         m_edit->setTextCursor(m_textCursor);
     } else {
+        qDebug() << "m_ColumnEditSelections.isEmpty() is false";
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_ColumnEditSelections[i].cursor.setPosition(m_beginPostion);
@@ -160,26 +200,34 @@ void DeleteTextUndoCommand2::undo()
             m_edit->setTextCursor(m_ColumnEditSelections[i].cursor);
         }
     }
+    qDebug() << "DeleteTextUndoCommand2 undo end";
 }
 
 void DeleteTextUndoCommand2::redo()
 {
+    qDebug() << "DeleteTextUndoCommand2 redo";
     if (m_ColumnEditSelections.isEmpty()) {
+        qDebug() << "m_ColumnEditSelections.isEmpty()";
         bool isEmptyLine = (m_sInsertText.size() == 0);
         bool isBlankLine = (m_sInsertText.trimmed().size() == 0);
 
         if (!m_iscurrLine) {
+            qDebug() << "m_iscurrLine is false";
             //删除到行尾
             if (isEmptyLine || m_textCursor.atBlockEnd()) {
+                qDebug() << "isEmptyLine || m_textCursor.atBlockEnd()";
                 m_textCursor.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor);
             } else if (isBlankLine && m_textCursor.atBlockStart()) {
+                qDebug() << "isBlankLine && m_textCursor.atBlockStart()";
                 m_textCursor.movePosition(QTextCursor::StartOfBlock);
                 m_textCursor.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
             } else {
+                qDebug() << "else";
                 m_textCursor.movePosition(QTextCursor::NoMove, QTextCursor::MoveAnchor);
                 m_textCursor.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
             }
         } else {
+            qDebug() << "m_iscurrLine is true";
             //删除整行
             m_textCursor.movePosition(QTextCursor::StartOfBlock, QTextCursor::MoveAnchor);
             m_textCursor.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
@@ -193,6 +241,7 @@ void DeleteTextUndoCommand2::redo()
         // 进行撤销/恢复时将光标移动到撤销位置
         m_edit->setTextCursor(m_textCursor);
     } else {
+        qDebug() << "m_ColumnEditSelections.isEmpty() is false";
         int cnt = m_ColumnEditSelections.size();
         for (int i = 0; i < cnt; i++) {
             m_beginPostion = m_ColumnEditSelections[i].cursor.selectionStart();
@@ -200,4 +249,5 @@ void DeleteTextUndoCommand2::redo()
             m_edit->setTextCursor(m_ColumnEditSelections[i].cursor);
         }
     }
+    qDebug() << "DeleteTextUndoCommand2 redo end";
 }
