@@ -3,7 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "replaceallcommond.h"
-
+#include <QDebug>
 
 
 ReplaceAllCommand::ReplaceAllCommand(QString &oldText, QString &newText, QTextCursor cursor, QUndoCommand *parent)
@@ -12,16 +12,18 @@ ReplaceAllCommand::ReplaceAllCommand(QString &oldText, QString &newText, QTextCu
     , m_newText(newText)
     , m_cursor(cursor)
 {
-
+    qDebug() << "ReplaceAllCommand created - oldText length:" << oldText.length()
+             << "newText length:" << newText.length() << "cursor pos:" << cursor.position();
 }
 
 ReplaceAllCommand::~ReplaceAllCommand()
 {
-
+    qDebug() << "ReplaceAllCommand destroyed";
 }
 
 void ReplaceAllCommand::redo()
 {
+    qInfo() << "ReplaceAllCommand redo - replacing all text with new text (length:" << m_newText.length() << ")";
     m_cursor.setPosition(0);
     m_cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
     m_cursor.deleteChar();
@@ -31,6 +33,7 @@ void ReplaceAllCommand::redo()
 
 void ReplaceAllCommand::undo()
 {
+    qInfo() << "ReplaceAllCommand undo - restoring original text (length:" << m_oldText.length() << ")";
     m_cursor.setPosition(0);
     m_cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
     m_cursor.deleteChar();
